@@ -1,6 +1,6 @@
 import re as _re
 import enum as _enum
-import pregex.exceptions as _exceptions
+import pregex.exceptions as _ex
 from typing import Iterator as _Iterator
 
 
@@ -11,10 +11,11 @@ class _Type(_enum.Enum):
     Alternation = 0
     Assertion = 1
     Class = 2
-    Group = 3
-    Other = 4
-    Quantifier = 5
-    Token = 6
+    Empty = 3
+    Group = 4
+    Other = 5
+    Quantifier = 6
+    Token = 7
 
 
 class Pregex():
@@ -22,7 +23,7 @@ class Pregex():
     Wraps the provided pattern within a "Pregex" instance.
 
     :param str pattern: The pattern that is to be wrapped within an instance of this class.
-    :param bool escape: Indicates whether to escape the provided pattern or not. Defaults to 'True'.
+    :param bool escape: Determines whether to escape the provided pattern or not. Defaults to 'True'.
 
     :raises NonStringArgumentException: Parameter 'pattern' is not a string.
 
@@ -31,18 +32,19 @@ class Pregex():
 
 
     '''
-    Indicates the groupping rules of each Pregex instance type:
+    Determines the groupping rules of each Pregex instance type:
 
-    :schema: __groupping_rules[type] => (on_concat, on_quantify)
+    :schema: __groupping_rules[type] => (on_concat, on_quantify, on_assertion)
     '''
     __groupping_rules: dict[_Type, str] = {
-        _Type.Alternation: (True, True),
-        _Type.Assertion : (False, True),
-        _Type.Class: (False, False),
-        _Type.Group: (False, False),
-        _Type.Other: (False, True),
-        _Type.Quantifier: (False, True),
-        _Type.Token: (False, False),
+        _Type.Alternation: (True, True, True),
+        _Type.Assertion : (False, True, False),
+        _Type.Class: (False, False, False),
+        _Type.Empty: (False, False, False),
+        _Type.Group: (False, False, False),
+        _Type.Other: (False, True, False),
+        _Type.Quantifier: (False, True, False),
+        _Type.Token: (False, False, False),
     }
 
     '''
@@ -56,14 +58,14 @@ class Pregex():
         Wraps the provided pattern within a "Pregex" instance.
 
         :param str pattern: The pattern that is to be wrapped within an instance of this class.
-        :param bool escape: Indicates whether to escape the provided pattern or not. Defaults to 'True'.
+        :param bool escape: Determines whether to escape the provided pattern or not. Defaults to 'True'.
 
         :raises NonStringArgumentException: Parameter 'pattern' is not a string.
 
         :note: This class constitutes the base class for every other class within the pregex package.
         '''
         if not isinstance(pattern, str):
-            raise _exceptions.NonStringArgumentException()
+            raise _ex.NonStringArgumentException()
         if escape:
             self.__pattern = __class__.__escape(pattern)
         else:
@@ -79,7 +81,7 @@ class Pregex():
         '''
         Returns the expression's pattern as its string representation.
 
-        :param bool include_falgs: Indicates whether to display the RegEx flags \
+        :param bool include_falgs: Determines whether to display the RegEx flags \
             along with the pattern. Defaults to 'False'.
 
         :note: This method is to be preferred over str() when one needs to display \
@@ -93,7 +95,7 @@ class Pregex():
         '''
         Returns the expression's compiled pattern as a 're.Pattern' instance.
         
-        :param bool discard_after: Indicates whether the compiled pattern is to be \
+        :param bool discard_after: Determines whether the compiled pattern is to be \
             discarded after this method, or to be retained so that any further attempt \
             at matching a string will use the compiled pattern instead of the regular one. \
             Defaults to 'True'.
@@ -117,7 +119,7 @@ class Pregex():
 
     def has_match(self, text: str) -> bool:
         '''
-        Returns 'True' if at least one match is found within the provided piece of text.
+        Returns 'True' if at least one match is found within the provided text.
 
         :param str text: The piece of text that is to be searched for matches.
         '''
@@ -127,7 +129,7 @@ class Pregex():
 
     def is_exact_match(self, text: str) -> bool:
         '''
-        Returns 'True' only if the provided piece of text matches this pattern exactly.
+        Returns 'True' only if the provided text matches this pattern exactly.
 
         :param str text: The piece of text that is to be searched for matches.
         '''
@@ -137,7 +139,7 @@ class Pregex():
 
     def iterate_matches(self, text: str) -> _Iterator[str]:
         '''
-        Generates any possible matches found within the provided piece of text.
+        Generates any possible matches found within the provided text.
 
         :param str text: The piece of text that is to be searched for matches.
         '''
@@ -147,7 +149,7 @@ class Pregex():
 
     def iterate_matches_and_pos(self, text: str) -> _Iterator[tuple[str, int, int]]:
         '''
-        Generates any possible matches found within the provided piece of text \
+        Generates any possible matches found within the provided text \
         along with their exact position.
 
         :param str text: The piece of text that is to be searched for matches.
@@ -164,7 +166,7 @@ class Pregex():
         then that capture's corresponding value will be 'None'.
 
         :param str text: The piece of text that is to be searched for matches.
-        :param bool include_empty: Indicates whether to include empty captures into the \
+        :param bool include_empty: Determines whether to include empty captures into the \
             results. Defaults to 'True'.
         '''
         for match in self.__iterate_match_objects(text):
@@ -181,7 +183,7 @@ class Pregex():
         '(None, -1, -1)'.
 
         :param str text: The piece of text that is to be searched for matches.
-        :param bool include_empty: Indicates whether to include empty captures into the \
+        :param bool include_empty: Determines whether to include empty captures into the \
             results. Defaults to 'True'.
         :param bool relative_to_match: If 'True', then each group's position-indices are calculated \
             relative to the group's corresponding match, not to the whole string. Defaults to 'False'.
@@ -200,7 +202,7 @@ class Pregex():
 
     def get_matches(self, text: str) -> list[str]:
         '''
-        Returns a list containing any possible matches found within the provided piece of text.
+        Returns a list containing any possible matches found within the provided text.
 
         :param str text: The piece of text that is to be searched for matches.
         '''
@@ -209,7 +211,7 @@ class Pregex():
 
     def get_matches_and_pos(self, text: str) -> list[tuple[str, int, int]]:
         '''
-        Returns a list containing any possible matches found within the provided piece of text \
+        Returns a list containing any possible matches found within the provided text \
         along with their exact position.
 
         :param str text: The piece of text that is to be searched for matches.
@@ -225,7 +227,7 @@ class Pregex():
         then that capture's corresponding value will be 'None'.
 
         :param str text: The piece of text that is to be searched for matches.
-        :param bool include_empty: Indicates whether to include empty captures into the \
+        :param bool include_empty: Determines whether to include empty captures into the \
             results. Defaults to 'True'.
         '''
         return list(group for group in self.iterate_captures(text, include_empty))
@@ -240,7 +242,7 @@ class Pregex():
         corresponding tuple will be '(None, -1, -1)'.
 
         :param str text: The piece of text that is to be searched for matches.
-        :param bool include_empty: Indicates whether to include empty captures into the \
+        :param bool include_empty: Determines whether to include empty captures into the \
             results. Defaults to 'True'.
         :param bool relative_to_match: If 'True', then each group's position-indices are calculated \
             relative to the group's corresponding match, not to the whole string. Defaults to 'False'.
@@ -259,9 +261,11 @@ class Pregex():
         :param int count: The number of matches that are to be replaced, \
             starting from left to right. A value of '0' indicates that \
             all matches must be replaced. Defaults to '0'.
+
+        :raises NegativeArgumentException: Parameter "count" is less than zero.
         '''
         if count < 0:
-            raise _exceptions.NegativeArgumentException(count)
+            raise _ex.NegativeArgumentException("count", count)
         return _re.sub(str(self), repl, text, count, flags=self.__flags)
 
 
@@ -290,7 +294,7 @@ class Pregex():
         list containing each individual part of the text after the split.
 
         :param str text: The piece of text that is to be matched and split.
-        :param bool include_empty: Indicates whether to include empty groups into the results. \
+        :param bool include_empty: Determines whether to include empty groups into the results. \
             Defaults to 'True'.
         '''
         split_list, index = list(), 0
@@ -332,6 +336,14 @@ class Pregex():
         return self._non_capturing_group() if self.__get_group_on_quantify_rule() else str(self)
 
 
+    def _assert_conditional_group(self) -> str:
+        '''
+        Returns this instance's pattern wrapped within a non-capturing group
+        only if the instance's group-on-assertion rule is set to "True".
+        '''
+        return self._non_capturing_group() if self.__get_group_on_assert_rule() else str(self)
+
+
     def _to_pregex(pre: 'Pregex' or str) -> 'Pregex':
         '''
         Returns 'pre' exactly as provided if it is a "Pregex" instance, \
@@ -348,7 +360,7 @@ class Pregex():
         elif issubclass(pre.__class__, __class__):
             return pre
         else:
-            raise _exceptions.NeitherStringNorPregexException()
+            raise _ex.NeitherStringNorPregexException()
 
 
     ''' 
@@ -373,34 +385,24 @@ class Pregex():
 
     def __add__(self, pre: str or 'Pregex') -> 'Pregex':
         '''
-        Calls "self._add" in order to concatenate this instance with the provided \
-        string or "Pregex" instance, and returns the resulting "Pregex" instance.
+        Concatenates self with the provided string or "Pregex" instance,
+        and returns the resulting "Pregex" instance.
 
         :param pre: The string or "pregex" instance that is to be concatenated with \
             this instance. 
         '''
-        return __class__.__add(self, pre)
+        return __class__(self._concat(__class__._to_pregex(pre)), escape=False)
 
 
     def __radd__(self, pre: str or 'Pregex') -> 'Pregex':
         '''
-        Invokes "self._add" in order to concatenate the provided string or "Pregex" instance \
-        with this instance, and returns the resulting "Pregex" instance.
+        Concatenates self with the provided string or "Pregex" instance,
+        and returns the resulting "Pregex" instance.
 
         :param pre: The string or "pregex" instance that is to be concatenated with \
             this instance. 
         '''
-        return __class__.__add(pre, self)
-
-
-    def __add(pre1: 'Pregex' or str, pre2: 'Pregex' or str) -> 'Pregex':
-        '''
-        Concatenates "pre1" and "pre2" together and returns the resulting "Pregex" instance.
-
-        :param Pregex | str pre1: The string or a "Pregex" instance at the left side of the concatenation.
-        :param Pregex | str pre2: The string or a "Pregex" instance at the right side of the concatenation.
-        '''
-        return __class__(__class__._to_pregex(pre1)._concat(__class__._to_pregex(pre2)), escape=False)
+        return __class__(__class__._to_pregex(pre)._concat(self), escape=False)
 
 
     def __mul__(self, n: int) -> 'Pregex':
@@ -411,15 +413,16 @@ class Pregex():
         :param int n: The parameter "n" provided to the "self.exactly" method.
 
         :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
-        :raises NonPositiveArgumentException: Parameter 'n' is less than one.
-        :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
+        :raises NegativeArgumentException: Parameter 'n' is less than zero.
+        :raises CannotBeQuantifiedException: This class is applied to an instance \
+            that represents an "assertion" pattern.
         '''
         if self.__type == _Type.Assertion:
-            raise _exceptions.CannotBeQuantifiedException(self)
+            raise _ex.CannotBeQuantifiedException(self)
         if not isinstance(n, int) or isinstance(n, bool):
-            raise _exceptions.NonIntegerArgumentException(n)
-        if n < 1:
-            raise _exceptions.NonPositiveArgumentException(n)
+            raise _ex.NonIntegerArgumentException(n)
+        if n < 0:
+            raise _ex.NegativeArgumentException("n", n)
         return __class__(self._exactly(n), escape=False)
 
 
@@ -430,16 +433,16 @@ class Pregex():
 
         :param int n: The parameter "n" provided to the "self.exactly" method.
 
-        :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
-        :raises NonPositiveArgumentException: Parameter 'n' is less than one.
+        :raises NonIntegerArgumentException: Parameter "n" is not an integer.
+        :raises NegativeArgumentException: Parameter "n" is less than zero.
         :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
         '''
         if self.__type == _Type.Assertion:
-            raise _exceptions.CannotBeQuantifiedException(self)
+            raise _ex.CannotBeQuantifiedException(self)
         if not isinstance(n, int) or isinstance(n, bool):
-            raise _exceptions.NonIntegerArgumentException(n)
-        if n < 1:
-            raise _exceptions.NonPositiveArgumentException(n)
+            raise _ex.NonIntegerArgumentException(n)
+        if n < 0:
+            raise _ex.NegativeArgumentException("n", n)
         return __class__(self._exactly(n), escape=False)
 
 
@@ -457,6 +460,13 @@ class Pregex():
         return __class__.__groupping_rules[self.__type][1]
 
 
+    def __get_group_on_assert_rule(self) -> bool:
+        '''
+        Returns this instance's group-on-assert rule.
+        '''
+        return __class__.__groupping_rules[self.__type][2]
+
+
     def __iterate_match_objects(self, text: str) -> _Iterator[_re.Match]:
         '''
         Invokes "re.finditer" in order to iterate over all matches of this \
@@ -487,53 +497,77 @@ class Pregex():
 
         :param str pattern: The RegEx pattern that is to be examined.
         '''
-        if _re.fullmatch(r"\\?.", pattern, flags=__class__.__flags) is not None:
-            return _Type.Token if _re.fullmatch(r"\.|\\(?:w|d|s)",
-                pattern, flags=__class__.__flags | _re.IGNORECASE) is None \
-                else _Type.Class
+
+        def remove_groups(pattern: str, repl: str = ""):
+            '''
+            Removes all groups from the provided pattern, and replaces them with 'repl'.
+
+            :param str pattern: The pattern whose groups are to be removed.
+            :param str repl: The string that replaces all groups within the pattern.
+            '''
+            left_par, right_par = r"(?:(?<!\\)\()", r"(?:(?<!\\)\))"
+            if len(_re.findall(left_par, pattern)) == 0:
+                return pattern
+            temp = _re.sub(pattern=left_par + r"(?:[^\(\)]|\\(?:\(|\)))+" + right_par,
+                repl=repl, string=pattern)
+            return temp if temp == repl else remove_groups(temp, repl)
+
+        def __is_group(pattern: str) -> bool:
+            '''
+            Looks at the underlying pattern of this instance, and returns either \
+            "True" or "False", depending on whether the provided RegEx pattern \
+            represents a group or not.
+
+            :param str pattern: The pattern that is to be examined.
+            '''
+            if pattern.startswith('(') and pattern.endswith(')'):
+                n_open = 0
+                for i in range(1, len(pattern) - 1):
+                    prev_char, curr_char = pattern[i-1], pattern[i]
+                    if prev_char != "\\": 
+                        if curr_char == ')':
+                            if n_open == 0:
+                                return False
+                            else:
+                                n_open -= 1
+                        if curr_char == '(':
+                            n_open += 1
+                return n_open == 0
+            return False
+
+        # Replace escaped backslashes with some other character.
+        pattern = _re.sub(r"\\{2}", "a", pattern)
+
+        if pattern == "":
+            return _Type.Empty
+        elif __is_group(pattern):
+            return _Type.Group
+        elif _re.fullmatch(r"\\?.", pattern, flags=__class__.__flags) is not None:
+            if _re.fullmatch(r"\.|\\(?:w|d|s)", pattern,
+                flags=__class__.__flags | _re.IGNORECASE) is not None:
+                return _Type.Class
+            elif _re.fullmatch(r"\.|\\(?:b|B)", pattern,
+                flags=__class__.__flags | _re.IGNORECASE) is not None:
+                return _Type.Assertion
+            else:
+                return _Type.Token
         elif _re.fullmatch(r"\[.+\]", pattern) is not None:
             return _Type.Class
-        elif _re.fullmatch(r"(?:\^|\\A|\\b|\(\?<(?:=|!).+\)).+|.+(?:\$|\\Z|\\b|\(\?(?:=|!).+\))",
+
+        # Remove any groups.
+        temp = remove_groups(pattern)
+
+        if len(_re.split(pattern=r"(?<!\\)\|", string=temp)) > 1:
+                return _Type.Alternation
+        elif _re.fullmatch(r"(?:\^|\\A|\\b|\\B|\(\?<(?:=|!).+\)).+|.+(?:\$|\\Z|\\b|\\B|\(\?(?:=|!).+\))",
             pattern, flags=__class__.__flags) is not None:
             return _Type.Assertion
-        elif _re.fullmatch(r"(?:\\.|\([^\(\)]+\)|[^\\])(?:\?|\*|\+|\{(?:\d+|\d+,|,\d+|\d+,\d+)\})",
-            pattern, flags=__class__.__flags) is not None:
+        elif _re.fullmatch(r"(?:\\.|[^\\])?(?:\?|\*|\+|\{(?:\d+|\d+,|,\d+|\d+,\d+)\})",
+            temp, flags=__class__.__flags) is not None:
             return _Type.Quantifier
-        elif __class__.__is_group(pattern):
-            return _Type.Group
-        else:
-            pattern = _re.sub(
-                pattern=r"(?<!\\)\((?:(?<=\\)\)|[^\)])+\|(?:(?<=\\)\)|[^\)])+(?<!\\)\)",
-                repl="", string=pattern)
-            if len(_re.split(pattern=r"(?<!\\)\|", string=pattern)) > 1:
-                return _Type.Alternation
         return _Type.Other
 
 
-    def __is_group(pattern) -> bool:
-        '''
-        Looks at the underlying pattern of this instance, and returns either \
-        "True" or "False", depending on whether the provided RegEx pattern \
-        represents a group or not.
-
-        :param str pattern: The pattern that is to be examined.
-        '''
-        if pattern.startswith('(') and pattern.endswith(')'):
-            n_open = 0
-            for i in range(1, len(pattern) - 1):
-                prev_char, curr_char = pattern[i-1], pattern[i]
-                if prev_char != "\\": 
-                    if curr_char == ')':
-                        if n_open == 0:
-                            return False
-                        else:
-                            n_open -= 1
-                    if curr_char == '(':
-                        n_open += 1
-            return n_open == 0
-        return False
-
-
     '''
     Quantifiers
     '''
@@ -542,7 +576,7 @@ class Pregex():
         Applies quantifier "?" on this instance's underlying pattern and \
         returns the resulting pattern as a string.
 
-        :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
+        :param bool is_greedy: Determines whether to declare this quantifier as greedy. \
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
         '''
@@ -554,7 +588,7 @@ class Pregex():
         Applies quantifier "*" on this instance's underlying pattern and \
         returns the resulting pattern as a string.
 
-        :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
+        :param bool is_greedy: Determines whether to declare this quantifier as greedy. \
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
         '''
@@ -566,7 +600,7 @@ class Pregex():
         Applies quantifier "+" on this instance's underlying pattern and \
         returns the resulting pattern as a string.
 
-        :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
+        :param bool is_greedy: Determines whether to declare this quantifier as greedy. \
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
         '''
@@ -580,6 +614,8 @@ class Pregex():
 
         :param int n: The exact number of times that the provided pattern is to be matched.
         '''
+        if n == 0:
+            return str(Empty())
         if n == 1:
             return str(self)
         else:
@@ -592,7 +628,7 @@ class Pregex():
         returns the resulting pattern as a string.
 
         :param int n: The minimum number of times that the provided pattern is to be matched.
-        :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
+        :param bool is_greedy: Determines whether to declare this quantifier as greedy. \
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
         '''
@@ -610,7 +646,7 @@ class Pregex():
         returns the resulting pattern as a string.
 
         :param int n: The maximum number of times that the provided pattern is to be matched.
-        :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
+        :param bool is_greedy: Determines whether to declare this quantifier as greedy. \
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
         '''
@@ -627,12 +663,14 @@ class Pregex():
 
         :param int min: The minimum number of times that the provided pattern is to be matched.
         :param int max: The maximum number of times that the provided pattern is to be matched.
-        :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
+        :param bool is_greedy: Determines whether to declare this quantifier as greedy. \
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
         '''
         if min == max:
             return self._exactly(min)
+        elif min == 0 and max == 1:
+            return self._optional(is_greedy)
         else:
             return f"{self._quantify_conditional_group()}{{{min},{max}}}{'' if is_greedy else '?'}"
 
@@ -656,9 +694,11 @@ class Pregex():
         Applies the "alternation" operator on this instance's underlying pattern and \
         the provided pattern, and returns the resulting pattern as a string.
 
-        :param Pregex pre: A "Pregex" instance containing he pattern on the right side \
-            of the alternation.
+        :param Pregex pre: A "Pregex" instance containing the pattern on the \
+            right side of the alternation.
         '''
+        if pre._get_type() == _Type.Empty:
+            return str(self)
         return f"{self}|{pre}"
 
 
@@ -724,7 +764,7 @@ class Pregex():
         Applies assertion "\A" on this instance's underlying pattern and \
         returns the resulting pattern as a string.
         '''
-        return f"\\A{self}"
+        return f"\\A{self._assert_conditional_group()}"
 
 
     def _match_at_end(self) -> str:
@@ -732,7 +772,7 @@ class Pregex():
         Applies assertion "\Z" on this instance's underlying pattern and \
         returns the resulting pattern as a string.
         '''
-        return f"{self}\\Z"
+        return f"{self._assert_conditional_group()}\\Z"
 
 
     def _match_at_line_start(self) -> str:
@@ -740,7 +780,7 @@ class Pregex():
         Applies assertion "^" on this instance's underlying pattern and \
         returns the resulting pattern as a string.
         '''
-        return f"^{self}"
+        return f"^{self._assert_conditional_group()}"
 
 
     def _match_at_line_end(self) -> str:
@@ -748,31 +788,7 @@ class Pregex():
         Applies assertion "$" on this instance's underlying pattern and \
         returns the resulting pattern as a string.
         '''
-        return f"{self}$"
-
-
-    def _match_at_word_boundary(self) -> str:
-        '''
-        Applies assertion "\\b" on both sides of this instance's underlying pattern \
-        and returns the resulting pattern as a string.
-        '''
-        return f"\\b{self}\\b"
-
-
-    def _match_at_left_word_boundary(self) -> str:
-        '''
-        Applies assertion "\\b" on the left side  of this instance's underlying pattern \
-        and returns the resulting pattern as a string.
-        '''
-        return f"\\b{self}"
-
-
-    def _match_at_right_word_boundary(self) -> str:
-        '''
-        Applies assertion "\\b" on the right side  of this instance's underlying pattern \
-        and returns the resulting pattern as a string.
-        '''
-        return f"{self}\\b"
+        return f"{self._assert_conditional_group()}$"
 
 
     def _followed_by(self, pre: 'Pregex') -> str:
@@ -782,7 +798,9 @@ class Pregex():
 
         :param Pregex | str pre: The non-matching pattern of the assertion.
         '''
-        return f"{self}(?={pre})"
+        if pre._get_type() == _Type.Empty:
+            return str(self)
+        return f"{self._assert_conditional_group()}(?={pre})"
 
 
     def _not_followed_by(self, pre: str) -> 'Pregex':
@@ -792,7 +810,9 @@ class Pregex():
 
         :param Pregex pre: The non-matching pattern of the assertion.
         '''
-        return f"{self}(?!{pre})"
+        if pre._get_type() == _Type.Empty:
+            return str(self)
+        return f"{self._assert_conditional_group()}(?!{pre})"
 
 
     def _preceded_by(self, pre: 'Pregex') -> str:
@@ -802,8 +822,9 @@ class Pregex():
 
         :param Pregex pre: The non-matching pattern of the assertion.
         '''
-
-        return f"(?<={pre}){self}"
+        if pre._get_type() == _Type.Empty:
+            return str(self)
+        return f"(?<={pre}){self._assert_conditional_group()}"
 
 
     def _not_preceded_by(self, pre: 'Pregex') -> str:
@@ -813,4 +834,171 @@ class Pregex():
 
         :param Pregex pre: The non-matching pattern of the assertion.
         '''
-        return f"(?<!{pre}){self}"
\ No newline at end of file
+        if pre._get_type() == _Type.Empty:
+            return str(self)
+        return f"(?<!{pre}){self._assert_conditional_group()}"
+
+
+class Empty(Pregex):
+    '''
+    Matches the empty string "".
+
+    :note: Applying a quantifer to Empty results in Empty.
+    :note: Applying a group to Empty results in Empty.
+    :note: Applying an operator between Empty and pattern P results in P.
+    :note: Applying an assertion to Empty results in the assertion.
+    '''
+
+    def __init__(self) -> 'Empty':
+        '''
+        Matches the empty string "".
+
+        :note: Applying a quantifer to Empty results in Empty.
+        :note: Applying a group to Empty results in Empty.
+        :note: Applying an operator between Empty and pattern P results in P.
+        :note: Applying an assertion to Empty results the assertion itself.
+        '''
+        super().__init__("")
+
+
+    def __mul__(self, n: int) -> 'Empty':
+        '''
+        Returns self. \
+
+        :param int n: Does nothing.
+
+        :raises NonIntegerArgumentException: Parameter "n" is not an integer.
+        :raises NegativeArgumentException: Parameter "n" is less than zero.
+        '''
+        if not isinstance(n, int) or isinstance(n, bool):
+            raise _ex.NonIntegerArgumentException(n)
+        if n < 0:
+            raise _ex.NegativeArgumentException("n", n)
+        return self
+
+
+    def __rmul__(self, n: int) -> 'Empty':
+        '''
+        Returns self. \
+
+        :param int n: Does nothing.
+
+        :raises NonIntegerArgumentException: Parameter "n" is not an integer.
+        :raises NegativeArgumentException: Parameter "n" is less than zero.
+        '''
+        if not isinstance(n, int) or isinstance(n, bool):
+            raise _ex.NonIntegerArgumentException(n)
+        if n < 0:
+            raise _ex.NegativeArgumentException("n", n)
+        return self
+
+
+    def __add__(self, pre: str or Pregex) -> Pregex:
+        '''
+        Returns the provided string or "Pregex" instance as a "Pregex" instance.
+
+        :param pre: The string or "pregex" instance that is returned. 
+        '''
+        return __class__._to_pregex(pre)
+
+
+    def __radd__(self, pre: str or Pregex) -> Pregex:
+        '''
+        Returns the provided string or "Pregex" instance as a "Pregex" instance.
+
+        :param pre: The string or "pregex" instance that is to be concatenated with \
+            this instance. 
+        '''
+        return __class__._to_pregex(pre)
+
+    
+    def _optional(self, is_greedy: bool = True)-> str:
+        '''
+        Returns self as a string.
+
+        :param bool is_greedy: Does nothing.
+        '''
+        return str(self)
+
+
+    def _indefinite(self, is_greedy: bool = True) -> str:
+        '''
+        Returns self as a string.
+
+        :param bool is_greedy: Does nothing.
+        '''
+        return str(self)
+
+
+    def _one_or_more(self, is_greedy: bool = True) -> str:
+        '''
+        Returns self as a string.
+
+        :param bool is_greedy: Does nothing.
+        '''
+        return str(self)
+
+
+    def _exactly(self, n: int) -> str:
+        '''
+        Returns self as a string.
+
+        :param int n: Does nothing.
+        '''
+        return str(self)
+
+
+    def _at_least(self, n: int, is_greedy: bool = True)-> str:
+        '''
+        Returns self as a string.
+
+        :param int n: Does nothing.
+        :param bool is_greedy: Does nothing.
+        '''
+        return str(self)
+
+
+    def _at_most(self, n: int, is_greedy: bool = True) -> str:
+        '''
+        Returns self as a string.
+
+        :param int n: Does nothing.
+        :param bool is_greedy: Does nothing.
+        '''
+        return str(self)
+
+
+    def _at_least_at_most(self, min: int, max: int, is_greedy: bool = True) -> str:
+        '''
+        Returns self as a string.
+
+        :param int min: Does nothing.
+        :param int max: Does nothing.
+        :param bool is_greedy: Does nothing.
+        '''
+        return str(self)
+
+
+    def _either(self, pre: 'Pregex') -> str:
+        '''
+        Returns 'pre' as a string.
+
+        :param Pregex pre: The "Pregex" instance that is returned by this method.
+        '''
+        return str(pre)
+
+
+    def _capturing_group(self, name: str = '') -> str:
+        '''
+        Returns self as a string.
+
+        :param str name: Does nothing.
+        '''
+        return str(self)
+
+
+    def _non_capturing_group(self) -> str:
+        '''
+        Returns self as a string.
+        '''
+        return str(self)
\ No newline at end of file
