@@ -1,5 +1,5 @@
 import pregex.pre as _pre
-import pregex.exceptions as _exceptions
+import pregex.exceptions as _ex
 
 
 class __Quantifier(_pre.Pregex):
@@ -10,7 +10,7 @@ class __Quantifier(_pre.Pregex):
     '''
     def __init__(self, pre: _pre.Pregex or str, is_greedy: bool, transform) -> '__Quantifier':
         if (not isinstance(self, Optional)) and issubclass(pre.__class__, _pre.Pregex) and pre._get_type() == _pre._Type.Assertion:
-            raise _exceptions.CannotBeQuantifiedException(pre)
+            raise _ex.CannotBeQuantifiedException(pre)
         pattern = transform(__class__._to_pregex(pre), is_greedy)
         super().__init__(pattern, escape=False)
 
@@ -107,9 +107,11 @@ class Exactly(__Quantifier):
         or wrapped within a "Pregex" subtype instance.
     :param int n: The exact number of times that the provided pattern is to be matched.
 
-    :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
-    :raises NonPositiveArgumentException: Parameter 'n' is less than one.
+    :raises NonIntegerArgumentException: Parameter "n" is not an integer.
+    :raises NegativeArgumentException: Parameter "n" is less than zero.
     :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
+
+    :note: Providing the value zero as parameter "n" results in the "Empty" pattern.
     '''
 
     def __init__(self, pre: _pre.Pregex or str, n: int) -> _pre.Pregex:
@@ -120,14 +122,16 @@ class Exactly(__Quantifier):
             or wrapped within a "Pregex" subtype instance.
         :param int n: The exact number of times that the provided pattern is to be matched.
 
-        :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
-        :raises NonPositiveArgumentException: Parameter 'n' is less than one.
+        :raises NonIntegerArgumentException: Parameter "n" is not an integer.
+        :raises NegativeArgumentException: Parameter "n" is less than zero.
         :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
+
+        :note: Providing the value zero as parameter "n" results in the "Empty" pattern.
         '''
         if not isinstance(n, int) or isinstance(n, bool):
-            raise _exceptions.NonIntegerArgumentException(n)
-        if n < 1:
-            raise _exceptions.NonPositiveArgumentException(n)
+            raise _ex.NonIntegerArgumentException(n)
+        if n < 0:
+            raise _ex.NegativeArgumentException("n", n)
         super().__init__(pre, False, lambda pre, _: pre._exactly(n))
 
 
@@ -142,8 +146,8 @@ class AtLeast(__Quantifier):
         When declared as such, the regex engine will try to match \
         the expression as many times as possible. Defaults to 'True'.
 
-    :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
-    :raises NegativeArgumentException: Parameter 'n' is less than zero.
+    :raises NonIntegerArgumentException: Parameter "n" is not an integer.
+    :raises NegativeArgumentException: Parameter "n" is less than zero.
     :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
     '''
 
@@ -158,14 +162,14 @@ class AtLeast(__Quantifier):
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
 
-        :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
-        :raises NegativeArgumentException: Parameter 'n' is less than zero.
+        :raises NonIntegerArgumentException: Parameter "n" is not an integer.
+        :raises NegativeArgumentException: Parameter "n" is less than zero.
         :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
         '''
         if not isinstance(n, int) or isinstance(n, bool):
-            raise _exceptions.NonIntegerArgumentException(n)
+            raise _ex.NonIntegerArgumentException(n)
         if n < 0:
-            raise _exceptions.NegativeArgumentException(n)
+            raise _ex.NegativeArgumentException("n", n)
         super().__init__(pre, is_greedy, lambda pre, is_greedy: pre._at_least(n, is_greedy))
 
 
@@ -180,9 +184,11 @@ class AtMost(__Quantifier):
         When declared as such, the regex engine will try to match \
         the expression as many times as possible. Defaults to 'True'.
 
-    :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
-    :raises NonPositiveArgumentException: Parameter 'n' is less than one.
+    :raises NonIntegerArgumentException: Parameter "n" is not an integer.
+    :raises NonPositiveArgumentException: Parameter "n" is less than one.
     :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
+
+    :note: Providing the value zero as parameter "n" results in the "Empty" pattern.
     '''
 
     def __init__(self, pre: _pre.Pregex or str, n: int, is_greedy: bool = True) -> _pre.Pregex:
@@ -196,14 +202,16 @@ class AtMost(__Quantifier):
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
 
-        :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
-        :raises NonPositiveArgumentException: Parameter 'n' is less than one.
+        :raises NonIntegerArgumentException: Parameter "n" is not an integer.
+        :raises NonPositiveArgumentException: Parameter "n" is less than one.
         :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
+
+        :note: Providing the value zero as parameter "n" results in the "Empty" pattern.
         '''
         if not isinstance(n, int) or isinstance(n, bool):
-            raise _exceptions.NonIntegerArgumentException(n)
+            raise _ex.NonIntegerArgumentException(n)
         if n < 1:
-            raise _exceptions.NonPositiveArgumentException(n)
+            raise _ex.NonPositiveArgumentException("n", n)
         super().__init__(pre, is_greedy, lambda pre, is_greedy: pre._at_most(n, is_greedy))
 
 
@@ -219,11 +227,13 @@ class AtLeastAtMost(__Quantifier):
         When declared as such, the regex engine will try to match \
         the expression as many times as possible. Defaults to 'True'.
 
-    :raises NonIntegerArgumentException: Either one of parameters 'min' or 'max' is not an integer.
-    :raises NegativeArgumentException: 'min' is less than zero.
-    :raises NonPositiveArgumentException: 'max' is less than one.
-    :raises MinGreaterThanMaxException: 'min' is greater than max.
+    :raises NonIntegerArgumentException: Either one of parameters "min" or "max" is not an integer.
+    :raises NegativeArgumentException: Either parameter "min" or "max" is less than zero.
+    :raises MinGreaterThanMaxException: Parameter "min" is greater than parameter "max".
     :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
+
+    :note: Parameter "is_greedy" has no effect in the case that "min" equals "max".
+    :note: Providing the value zero as both parameter "min" and "max" results in the "Empty" pattern.
     '''
 
     def __init__(self, pre: _pre.Pregex or str, min: int, max: int, is_greedy: bool = True) -> _pre.Pregex:
@@ -238,20 +248,22 @@ class AtLeastAtMost(__Quantifier):
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
 
-        :raises NonIntegerArgumentException: Either one of parameters 'min' or 'max' is not an integer.
-        :raises NegativeArgumentException: 'min' is less than zero.
-        :raises NonPositiveArgumentException: 'max' is less than one.
-        :raises MinGreaterThanMaxException: 'min' is greater than max.
+        :raises NonIntegerArgumentException: Either one of parameters "min" or "max" is not an integer.
+        :raises NegativeArgumentException: Either parameter "min" or "max" is less than zero.
+        :raises MinGreaterThanMaxException: Parameter "min" is greater than parameter "max".
         :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
+
+        :note: Parameter "is_greedy" has no effect in the case that "min" equals "max".
+        :note: Providing the value zero as both parameter "min" and "max" results in the "Empty" pattern.
         '''
         if not isinstance(min, int) or isinstance(min, bool):
-            raise _exceptions.NonIntegerArgumentException(min)
+            raise _ex.NonIntegerArgumentException(min)
         if not isinstance(max, int) or isinstance(max, bool):
-            raise _exceptions.NonIntegerArgumentException(max)
+            raise _ex.NonIntegerArgumentException(max)
         if min < 0:
-            raise _exceptions.NegativeArgumentException(min)
-        elif max < 1:
-            raise _exceptions.NonPositiveArgumentException(max)
+            raise _ex.NegativeArgumentException("min", min)
+        if max < 0:
+            raise _ex.NegativeArgumentException("max", max)
         elif max < min:
-            raise _exceptions.MinGreaterThanMaxException(min, max)
+            raise _ex.MinGreaterThanMaxException(min, max)
         super().__init__(pre, is_greedy, lambda pre, is_greedy: pre._at_least_at_most(min, max, is_greedy))
\ No newline at end of file
